#
# spec file for package libe-book
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libe-book
Version:        0.1.3
Release:        4.5
Summary:        A library to import non-HTML reflowable e-book formats
License:        MPL-2.0
Group:          Productivity/Publishing/Word
URL:            https://sourceforge.net/projects/libebook/
Source:         http://downloads.sourceforge.net/libebook/%{name}-%{version}.tar.xz
Patch0:         icu-68.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gperf
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(liblangtag)
BuildRequires:  pkgconfig(librevenge-0.0)
BuildRequires:  pkgconfig(librevenge-generators-0.0)
BuildRequires:  pkgconfig(librevenge-stream-0.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif

%description
%{name} is a library to import non-HTML reflowable e-book formats.
Currently supported are PalmDoc, TealDoc, Plucker eBook, eReader eBook,
FictionBook v.2, TCR, zTXT.

%define libname libe-book-0_1-1

%package -n %{libname}
Summary:        A library to import non-HTML reflowable e-book formats
Group:          System/Libraries

%description -n %{libname}
%{name} is a library to import non-HTML reflowable e-book formats.
Currently supported are PalmDoc, TealDoc, Plucker eBook, eReader eBook,
FictionBook v.2, TCR, zTXT.

%package devel
Summary:        A library to import non-HTML reflowable e-book formats
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       libstdc++-devel

%description devel
%{name} is a library to import non-HTML reflowable e-book formats.
Currently supported are PalmDoc, TealDoc, Plucker eBook, eReader eBook,
FictionBook v.2, TCR, zTXT.

%package devel-doc
Summary:        Documentation for the libe-book API
Group:          Documentation/Other
BuildArch:      noarch

%description devel-doc
This package contains documentation for the libe-book API.

%package tools
Summary:        Tools to transform e-books into other formats
Group:          Productivity/Publishing/Word

%description tools
Tools to transform e-books into other formats.
Currently supported: XHTML, raw, text.

%prep
%autosetup -p1

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure \
	--disable-werror \
	--enable-tests \
	--disable-static \
	--docdir=%{_docdir}/%{name} \
	--disable-silent-rules
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
rm -f %{buildroot}%{_datadir}/%{name}/html*.css
%fdupes -s %{buildroot}%{_docdir}/%{name}/html

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/*.so.*

%files devel
%doc COPYING NEWS TODO ChangeLog
%{_libdir}/*.so
%{_libdir}/pkgconfig/libe*.pc
%{_includedir}/libe*

%files devel-doc
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}

%files tools
%{_bindir}/*

%changelog
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Mon Dec 14 2020 Callum Farmer <gmbr3@opensuse.org>
- Add icu-68.patch: fix build with ICU 68
* Tue Jan  9 2018 jengelh@inai.de
- Cure linguistic problem in descriptions.
* Mon Jan  8 2018 tchvatal@suse.com
- Update to 0.1.3:
  * Fix various problems when reading broken files, found with the help of
    american-fuzzy-lop and oss-fuzz.
  * Fix build with boost >= 1.59.
  * Set default page margins. (tdf#94162)
  * Make output of ebook2* --help more compatible with help2man.
  * Check for librevenge-stream if tests are enabled. (gentoo#603098)
  * Require C++11 for build.
  * Drop outdated MSVC project files.
  * Fix several issues found by Coverity.
  * FictionBook v.2:
  * Use document language as default language for text.
  * Use note title as footnote mark.
  * Handle subscript and superscript.
  * Output content of <code> in monospace font.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Aug  1 2016 tchvatal@suse.com
- Disable sle11 support code
* Wed Nov 11 2015 idonmez@suse.com
- Fix compilation with boost 1.59
* Thu Feb  5 2015 p.drouand@gmail.com
- Update to version 0.1.2
  * Check arguments of public functions. Passing NULL no longer causes
    cash.
  * Use symbol visibility on Linux. The library only exports the two
    public functions now.
  * Fix handling of   *  *enable  *experimental configure option.
  * Fix various crashes and hangs when reading broken files, found
    with the help of american  *fuzzy  *lop.
  * Fix incorrect mime type for JPEG images that occurs occasionally
    in FB2 files.
  * Handle zipped files that contain more than one file.
  * Add support for headings.
  * Add support for text language.
  * Convert dimensions and font sizes correctly. This makes the
    output actually usable
  * Parse basic paragraph and character properties.
  * Add initial support for images. Only Plot tag is supported, as
    Canvas is much more complex and can contain other objects too,
    not just a single image.
  * Recognize GIF images too.
  * Parse important page properties, like dimensions and margins.
  * Substitute the default fonts embedded on the devices for Liberation fonts.
  * Try to reconstruct headings from table of contents.
* Tue Jun  3 2014 fstrba@suse.com
- Upgrade to upstream version 0.1.1
  * Fix various problems when using --disable-experimental.
  * Work around MSVC bug.
  * Fix parsing of zipped FictionBook 2 files.
* Mon May 26 2014 fstrba@suse.com
- Upgrade to upstream version 0.1.0
  * ABI change
  * Remove dependency on libwpd-devel
  * Add dependency on librevenge-devel
- License change
  * Released under MPL-2.0
* Thu May  1 2014 crrodriguez@opensuse.org
- Use -fvisibility-inlines-hidden here as well, saves around
  360 global symbol table entries.
* Thu Feb  6 2014 fcrozat@suse.com
- Fix license tag to LGPL-2.1+ or MPL-2.0
* Fri Nov 22 2013 tchvatal@suse.com
- Version bump to 0.0.2:
  * Fix installed headers
  * Various build fixes
* Fri Nov 15 2013 tchvatal@suse.com
- Bit of cleanup and sorting.
* Fri Nov 15 2013 tchvatal@suse.com
- Make the thing buildable without much fuzz.
* Fri Nov 15 2013 tchvatal@suse.com
- Initial commit for lib used in libreoffice-4.2
